@@ -8,6 +8,8 @@ from .signer import Signer
 
 from .endpoints import (
     CANCEL,
+    CANCEL_ORDERS,
+    CANCEL_MARKET_ORDERS,
     CANCEL_ALL,
     CREATE_API_KEY,
     DELETE_API_KEY,
@@ -31,6 +33,7 @@ from .clob_types import (
     OrderArgs,
     RequestArgs,
     TradeNotificationParams,
+    OrderBookSummary,
 )
 from .exceptions import PolyException
 from .http_helpers.helpers import (
@@ -41,9 +44,8 @@ from .http_helpers.helpers import (
     add_trade_notifications_query_params,
 )
 from py_order_utils.config import get_contract_config
-from py_order_utils.model import BUY as UtilsBuy
 from .constants import L0, L1, L1_AUTH_UNAVAILABLE, L2, L2_AUTH_UNAVAILABLE
-from .order_builder.constants import BUY, SELL
+from .utilities import parse_raw_orderbook_summary, generate_orderbook_summary_hash
 
 
 class ClobClient:
@@ -137,7 +139,6 @@ class ClobClient:
                 api_secret=creds_raw["secret"],
                 api_passphrase=creds_raw["passphrase"],
             )
-            self.logger.info(creds)
         except:
             self.logger.error("Couldn't parse created CLOB creds")
             return None
@@ -159,7 +160,6 @@ class ClobClient:
                 api_secret=creds_raw["secret"],
                 api_passphrase=creds_raw["passphrase"],
             )
-            self.logger.info(creds)
         except:
             self.logger.error("Couldn't parse derived CLOB creds")
             return None
@@ -256,6 +256,22 @@ class ClobClient:
         headers = create_level_2_headers(self.signer, self.creds, request_args)
         return delete("{}{}".format(self.host, CANCEL), headers=headers, data=body)
 
+    def cancel_orders(self, order_ids):
+        """
+        Cancels orders
+        Level 2 Auth required
+        """
+        self.assert_level_2_auth()
+        body = order_ids
+
+        request_args = RequestArgs(
+            method="DELETE", request_path=CANCEL_ORDERS, body=body
+        )
+        headers = create_level_2_headers(self.signer, self.creds, request_args)
+        return delete(
+            "{}{}".format(self.host, CANCEL_ORDERS), headers=headers, data=body
+        )
+
     def cancel_all(self):
         """
         Cancels all available orders for the user
@@ -266,6 +282,22 @@ class ClobClient:
         headers = create_level_2_headers(self.signer, self.creds, request_args)
         return delete("{}{}".format(self.host, CANCEL_ALL), headers=headers)
 
+    def cancel_market_orders(self, market: str = None, asset_id: str = None):
+        """
+        Cancels orders
+        Level 2 Auth required
+        """
+        self.assert_level_2_auth()
+        body = {"market": market, "asset_id": asset_id}
+
+        request_args = RequestArgs(
+            method="DELETE", request_path=CANCEL_MARKET_ORDERS, body=body
+        )
+        headers = create_level_2_headers(self.signer, self.creds, request_args)
+        return delete(
+            "{}{}".format(self.host, CANCEL_MARKET_ORDERS), headers=headers, data=body
+        )
+
     def get_orders(self, params: FilterParams = None):
         """
         Gets orders for the API key
@@ -277,11 +309,18 @@ class ClobClient:
         url = add_query_params("{}{}".format(self.host, ORDERS), params)
         return get(url, headers=headers)
 
-    def get_order_book(self, token_id):
+    def get_order_book(self, token_id) -> OrderBookSummary:
         """
         Fetches the orderbook for the token_id
         """
-        return get("{}{}?token_id={}".format(self.host, GET_ORDER_BOOK, token_id))
+        raw_obs = get("{}{}?token_id={}".format(self.host, GET_ORDER_BOOK, token_id))
+        return parse_raw_orderbook_summary(raw_obs)
+
+    def get_order_book_hash(self, orderbook: OrderBookSummary) -> str:
+        """
+        Calculates the hash for the given orderbook
+        """
+        return generate_orderbook_summary_hash(orderbook)
 
     def get_order(self, order_id):
         """
