@@ -1,4 +1,3 @@
-
 # Access levels
 L0 = 0
 L1 = 1
@@ -6,7 +5,7 @@ L2 = 2
 
 
 CREDENTIAL_CREATION_WARNING = """🚨🚨🚨
-Your credentials CANNOT be recovered after they've been created. 
+Your credentials CANNOT be recovered after they've been created.
 Be sure to store them safely!
 🚨🚨🚨"""
 
@@ -15,3 +14,7 @@ L1_AUTH_UNAVAILABLE = "A private key is needed to interact with this endpoint!"
 
 L2_AUTH_UNAVAILABLE = "API Credentials are needed to interact with this endpoint!"
 
+ZERO_ADDRESS = "0x0000000000000000000000000000000000000000"
+
+MUMBAI = 80001
+POLYGON = 137
