@@ -9,7 +9,9 @@ GET_ORDER = "/order/"
 ORDERS = "/orders"
 POST_ORDER = "/order"
 CANCEL = "/order"
+CANCEL_ORDERS = "/orders"
 CANCEL_ALL = "/cancel-all"
+CANCEL_MARKET_ORDERS = "/cancel-market-orders"
 MID_POINT = "/midpoint"
 PRICE = "/price"
 GET_LAST_TRADE_PRICE = "/last-trade-price"
